@@ -12,13 +12,11 @@ from PyQt4 import QtCore, QtGui
 from ui.mainWindow import MainWindow
 
 
-
-
 if __name__ == "__main__":
     import sys
     app = QtGui.QApplication(sys.argv)
     ui = MainWindow()
     ui.showFullScreen() 
-    ui.setWindowTitle('AnselA-Image Darkroom')
+    ui.setWindowTitle('Ansel-A:Digital Darkroom')
     ui.show()
     sys.exit(app.exec_()) 
