@@ -16,6 +16,7 @@ import ui.AnselA_Graphics as Graphics
 from PIL import Image
 from PIL import ImageDraw
 from PIL import ImageEnhance
+from subprocess import call
 
 from PyQt4 import *
 from PyQt4 import QtGui
@@ -172,30 +173,12 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             
             
             if cSource == "R":
-#                out0=source[R].point(lambda i: i * 3)
-#                source[R].paste(out0,  None,  None)
-#                out1=source[G].point(lambda i: i * 0)
-#                source[G].paste(out1,  None,  None)
-#                out2=source[B].point(lambda i: i * 0)
-#                source[B].paste(out2,  None,  None)
-#                im=Image.merge("RGB", (out0 ,  source[G],  source[B] ))
                 im = source[R].convert("L")
             elif cSource == "G":
-#                out=source[R].point(lambda i: i * 1)
-#                source[R].paste(out,  None,  None)
-#                out=source[G].point(lambda i: i * 1.9)
-#                source[G].paste(out,  None,  None)
-#                out=source[B].point(lambda i: i * 1)
-#                source[B].paste(out,  None,  None)
-#                im=Image.merge("RGB", (source[R] ,  source[G],  source[B] ))
-#                im=im.convert("L")
                 im = source[G].convert("L")
             elif cSource == "B":
-                #source[B].point(lambda i: i * 1.2)
                 im = source[B].convert("L")
             elif cSource == "C":
-#                source[B].point(lambda i: i * 1.2)
-#                source[G].point(lambda i: i * 1.2)
                 out = Image.merge("RGB", (N, source[G],  source[B]))
                 im = out.convert("L")
             elif cSource == "BC":
@@ -205,28 +188,22 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                 out = Image.merge("RGB", (source[R], source[B],  source[B]))
                 im = out.convert("L")
             elif cSource == "M":
-#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .5)
-#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .5)
-                out = Image.merge("RGB", (source[R], N,  source[B])  )
+                out = Image.merge("RGB", (source[R], N,  source[B]))
                 im = out.convert("L")
             elif cSource == "RM":
-#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
-#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
-                out = Image.merge("RGB", (source[R], source[R],  source[B]) )
+                out = Image.merge("RGB", (source[R], source[R],  source[B]))
                 im = out.convert("L")
             elif cSource == "RY":
-                out = Image.merge("RGB", (source[R], source[G],  source[R]) )
+                out = Image.merge("RGB", (source[R], source[G],  source[R]))
                 im = out.convert("L")
             elif cSource == "Y":
-#                source[R].point(lambda i: i * 1.66)
-#                source[G].point(lambda i: i * 1.66)
-                out = Image.merge("RGB", (source[R], source[G],  N) )
+                out = Image.merge("RGB", (source[R], source[G],  N))
                 im = out.convert("L")
             elif cSource == "GY":
-                out = Image.merge("RGB", (source[R], source[G],  source[G]) )
+                out = Image.merge("RGB", (source[R], source[G],  source[G]))
                 im = out.convert("L")                
             elif cSource == "GC":
-                out = Image.merge("RGB", (source[G], source[G],  source[B]) )
+                out = Image.merge("RGB", (source[G], source[G],  source[B]))
                 im = out.convert("L")    
             
             im = im.convert("RGB")
@@ -374,22 +351,22 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                 self.showUpdateLabel(True,  True)
                 
             im = imageToEdit
-                
-            if cSource =="Br": 
+            
+            if cSource =="Br":
                 enhancer = ImageEnhance.Brightness(im)
-                Eim = enhancer.enhance(self.val.valBr*-1*0.001)
+                Eim = enhancer.enhance(Core.valToScalar(self.val.valBr))
             if cSource =="Co":
                 enhancer = ImageEnhance.Contrast(im)
-                Eim = enhancer.enhance(self.val.valCo*-1*0.001) 
+                Eim = enhancer.enhance(Core.valToScalar(self.val.valCo)) 
             if cSource =="Sa":
                 enhancer = ImageEnhance.Color(im)
-                Eim = enhancer.enhance(self.val.valSa*-1*0.001) 
-            if cSource =="Sh":    
+                Eim = enhancer.enhance(Core.valToScalar(self.val.valSa)) 
+            if cSource =="Sh":
                 enhancer = ImageEnhance.Sharpness(im)
-                Eim = enhancer.enhance(self.val.valSh*-1*0.001) 
+                Eim = enhancer.enhance(Core.valToScalar(self.val.valSh)) 
             
             if (UpdateRealImage == True):
-                self.val.curIm = Eim
+                self.val.curThumb = Eim
                 self.photo.setPixmap(Core.pil2qpixmap(self.val.curIm))
                 self.showUpdateLabel(False,  False)
             else:
@@ -837,7 +814,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         Submit bug report to bugs.maemo.org
         """ 
-        webbrowser.open("https://bugs.maemo.org/enter_bug.cgi?product=AnselA")
+        url='https://bugs.maemo.org/enter_bug.cgi?product=AnselA'
+        os.system('browser --url=%s' %url)
 
     @pyqtSignature("")
     def on_btnPListCancel_released(self):
@@ -972,13 +950,14 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                         continue
                 
                 try:
+                    # Get the PListobject with predefined sizes
                     photoItem = PlistWidgetItem()
                     im=Image.open(self.val.thumbsDir+file,  "r" )
                     icon =QtGui.QIcon(self.val.thumbsDir+file)
                     photoItem.setIcon(icon)
                     photoItem.setText(file.replace(".jpg", ""))
                     photoItem.setIconSize(im.size[0], im.size[1])
-                    photoItem.setImageLocation(self.val.thumbsDir+file)
+                    #photoItem.setImageLocation(self.val.thumbsDir+file)
                     photoItem.setImageLocation(self.val.curImageLoc+file)
                     h, w = self.convertImSize(im.size[0], im.size[1],  400)
                     photoItem.setIconZoomSize(self.ScaleLabel(220,  380, w,  h))
@@ -1038,6 +1017,14 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         return QtCore.QRect(xW-int(w/2), yH-int(h/2), w, h)
 
+    
+    @pyqtSignature("")
+    def on_btnSaveAs_released(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
 
 class PlistWidgetItem(QtGui.QListWidgetItem):
     iconSize =(0, 0)
